# package_repo

################

**NB:** Add Azure DevOps CI/CD pipeline status badge:

Pipelines > package_repo > click on three dots in upper right corner > Status badge > Branch: develop > replace this instruction with a Sample markdown.

################

[![security: bandit](https://img.shields.io/badge/security-bandit-yellow.svg)](https://github.com/PyCQA/bandit)

Give a description of your repository here.

## Installation

Give a installation guide here, or provide one via a link. 

<!-- Replace the installation_guide_link to the installation guide of your repository -->
For example:
* Use [Installation guide](installation_guide_link) to setup your repository using this cookiecutter template.

## Documentation

<!-- Replace the documentation_link to the documentation of your repository -->
You can find the documentation of this repository [on this website](documentation_link).

## Examples

Here you can give some examples. Here is an example to get you started:

```bash
from package_repo import multiply
result = multiply(2, 3)
print(result)
```

This example shows how to use the multiply functionality within the repository.

## Resources

<!-- Replace the links to the corresponding urls of your repository -->
* [Releases](releases_link)
* [Documentation](documentation_link)
* [JIRA board](jira_link)